package X3D::FieldTypes::MFRotation;

our $VERSION = '0.009';

use X3D::Package 'MFRotation : X3DArrayField { [] }';

1;
__END__
